@@ -125,7 +125,7 @@ class Receiver(BaseModel):
 class PaymentData(BaseModel):
     transaction_id: Optional[str]
     paid_at: Optional[str]
-    expire_at: str
+    expire_at: Optional[str]
     amount: Optional[float]
     currency: CurrencyType
     type: Optional[PaymentType]
@@ -143,7 +143,7 @@ class PaymentData(BaseModel):
         validate_assignment = True
 
     paid_at_must_be_iso8601 = validator('paid_at', allow_reuse=True)(check_isoformat_none_case)
-    expire_at_must_be_iso8601 = validator('expire_at', allow_reuse=True)(check_iso_format)
+    expire_at_must_be_iso8601 = validator('expire_at', allow_reuse=True)(check_isoformat_none_case)
 
     def json(self):
         return json.dumps(self, cls=PaymentEncoder)
